@@ -3,7 +3,5 @@ date2jul1 <- function(d) {
 	
 	res <- .C("date2jul1",date=as.character(d),doy=integer(1),year=integer(1),PACKAGE="pheno")
 
-	attach(res)
-
-	return(list(doy=doy, year=year))
+	return(list(doy=res$doy, year=res$year))
 }
