@@ -6,7 +6,6 @@ daylength <- function(i,l) {
 	if(!is.integer(i)) stop("daylength: first argument must be an integer. Exiting ...")	
 	res <- .C("daylength",l=as.double(l),i=as.integer(i),dl=double(1),delta=double(1),PACKAGE="pheno")
 	
-	attach(res)
-	return(list(dl=dl, delata=delta))
+	return(list(dl=res$dl, delata=res$delta))
 
 }
